==> sui-login-password-reset-1.13.0.tgz: package/lib/domain/password/UseCases/ChangePasswordUseCase.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _applyDecoratedDescriptor from "@babel/runtime/helpers/esm/applyDecoratedDescriptor";
var _class;
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { inlineError } from '@s-ui/decorators';
import { UseCase } from '@s-ui/domain';
export var ChangePasswordUseCase = (_class = /*#__PURE__*/function (_UseCase) {
  _inheritsLoose(ChangePasswordUseCase, _UseCase);
  function ChangePasswordUseCase(_ref) {
    var _this;
    var config = _ref.config,
      changePasswordService = _ref.changePasswordService,
      changePasswordRequest = _ref.changePasswordRequest;
    _this = _UseCase.call(this) || this;
    _this._config = config;
    _this._changePasswordService = changePasswordService;
    _this._changePasswordRequest = changePasswordRequest;
    return _this;
  }
  var _proto = ChangePasswordUseCase.prototype;
  _proto.execute = /*#__PURE__*/function () {
    var _execute = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref2) {
      var password, token, changePasswordRequest, _yield$this$_changePa, error, result;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            password = _ref2.password, token = _ref2.token;
            changePasswordRequest = new this._changePasswordRequest({
              password: password,
              token: token
            });
            _context.next = 4;
            return this._changePasswordService.execute({
              changePasswordRequest: changePasswordRequest
            });
          case 4:
            _yield$this$_changePa = _context.sent;
            error = _yield$this$_changePa[0];
            result = _yield$this$_changePa[1];
            if (!error) {
              _context.next = 9;
              break;
            }
            throw error;
          case 9:
            return _context.abrupt("return", result);
          case 10:
          case "end":
            return _context.stop();
        }
      }, _callee, this);
    }));
    function execute(_x) {
      return _execute.apply(this, arguments);
    }
    return execute;
  }();
  return ChangePasswordUseCase;
}(UseCase), (_applyDecoratedDescriptor(_class.prototype, "execute", [inlineError], Object.getOwnPropertyDescriptor(_class.prototype, "execute"), _class.prototype)), _class);

==> sui-login-password-reset-1.37.0.tgz: package/lib/domain/password/UseCases/ChangePasswordUseCase.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _applyDecoratedDescriptor from "@babel/runtime/helpers/esm/applyDecoratedDescriptor";
var _class;
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { inlineError } from '@s-ui/decorators';
import { UseCase } from '@s-ui/domain';
export var ChangePasswordUseCase = (_class = /*#__PURE__*/function (_UseCase) {
  _inheritsLoose(ChangePasswordUseCase, _UseCase);
  function ChangePasswordUseCase(_ref) {
    var _this;
    var config = _ref.config,
      changePasswordService = _ref.changePasswordService,
      changePasswordRequest = _ref.changePasswordRequest;
    _this = _UseCase.call(this) || this;
    _this._config = config;
    _this._changePasswordService = changePasswordService;
    _this._changePasswordRequest = changePasswordRequest;
    return _this;
  }
  var _proto = ChangePasswordUseCase.prototype;
  _proto.execute = /*#__PURE__*/function () {
    var _execute = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref2) {
      var password, token, changePasswordRequest, _yield$this$_changePa, error, result;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            password = _ref2.password, token = _ref2.token;
            changePasswordRequest = this._changePasswordRequest({
              password: password,
              token: token
            });
            _context.next = 4;
            return this._changePasswordService.execute({
              changePasswordRequest: changePasswordRequest
            });
          case 4:
            _yield$this$_changePa = _context.sent;
            error = _yield$this$_changePa[0];
            result = _yield$this$_changePa[1];
            if (!error) {
              _context.next = 9;
              break;
            }
            throw error;
          case 9:
            return _context.abrupt("return", result);
          case 10:
          case "end":
            return _context.stop();
        }
      }, _callee, this);
    }));
    function execute(_x) {
      return _execute.apply(this, arguments);
    }
    return execute;
  }();
  return ChangePasswordUseCase;
}(UseCase), (_applyDecoratedDescriptor(_class.prototype, "execute", [inlineError], Object.getOwnPropertyDescriptor(_class.prototype, "execute"), _class.prototype)), _class);
